==> vtigercrm-5.3.0p0.tgz: modules/Help/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Help/language/en_us.lang.php,v 1.3 2005/01/25 06:05:36 jack Exp $
 * Description:  Defines the English language pack for the Account module.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Contas',
'LBL_MODULE_TITLE'=>'Contas: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Busca Conta',
'LBL_LIST_FORM_TITLE'=>'Lista Conta',
'LBL_NEW_FORM_TITLE'=>'Nova Conta',
'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a Conta.",
);

?>

==> vtigercrm-5.4.0.tgz: modules/Help/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Help/language/en_us.lang.php,v 1.3 2005/01/25 06:05:36 jack Exp $
 * Description:  Defines the English language pack for the Help.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Organizações',
'LBL_MODULE_TITLE'=>'Organizações: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Busca Organização',
'LBL_LIST_FORM_TITLE'=>'Lista Organização',
'LBL_NEW_FORM_TITLE'=>'Nova Organização',
'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a Organização.",
);

?>
